Package: assertive.base
Type: Package
Title: A Lightweight Core of the 'assertive' Package
Version: 0.0-9
Date: 2021-02-07
Author: Richard Cotton [aut, cre],
  Sunkyu Choi [trl],
  Ivanka Skakun [trl],
  Gergely Dar<c3><b3>czi [trl],
  Anton Antonov [trl],
  Hisham Ben Hamidane [trl],
  Anja Billing [trl],
  Aditya Bhagwat [trl],
  Rasmus B<c3><a5><c3><a5>th [trl],
  Mine Cetinkaya-Rundel [trl],
  Aspasia Chatziefthymiou [trl]
Maintainer: Richard Cotton <richierocks@gmail.com>
Authors@R: c(person("Richard", "Cotton", role = c("aut", "cre"), email =
    "richierocks@gmail.com"),
    person("Sunkyu", "Choi", role = "trl", email =
    "szc2010@qatar-med.cornell.edu"),
    person("Ivanka", "Skakun", role = "trl", email =
    "ivanka.skakun@gmail.com"),
    person("Gergely", "Dar<c3><b3>czi", role = "trl", email =
    "daroczig@rapporter.net"),
    person("Anton", "Antonov", role = "trl", email =
    "tonytonov@gmail.com"),
    person("Hisham", "Ben Hamidane", role = "trl", email =
    "hbh2002@qatar-med.cornell.edu"),
    person("Anja", "Billing", role = "trl", email =
    "anb2061@qatar-med.cornell.edu"),
    person("Aditya", "Bhagwat", role = "trl", email =
    "bhagwataditya@gmail.com"),
    person("Rasmus", "B<c3><a5><c3><a5>th", role = "trl", email =
    "rasmus.baath@lucs.lu.se"),
    person("Mine", "Cetinkaya-Rundel", role = "trl", email =
    "mine@stat.duke.edu"),
    person("Aspasia", "Chatziefthymiou", role = "trl", email =
    "asc2006@qatar-med.cornell.edu"))
Description: A minimal set of predicates and assertions used by the assertive
    package.  This is mainly for use by other package developers who want to
    include run-time testing features in their own packages.  End-users will
    usually want to use assertive directly.
URL: https://bitbucket.org/richierocks/assertive.base
BugReports: https://bitbucket.org/richierocks/assertive.base/issues
Depends: R (>= 3.5.0)
Imports: methods, utils
Suggests: testthat
License: GPL (>= 3)
LazyLoad: yes
LazyData: yes
Acknowledgments: Development of this package was partially funded by
        the Proteomics Core at Weill Cornell Medical College in Qatar
        <https://qatar-weill.cornell.edu>.  The Core is supported by
        'Biomedical Research Program' funds, a program funded by Qatar
        Foundation. Ukranian translations were supported by
        www.coupofy.com.
RoxygenNote: 7.1.1
ByteCompile: true
NeedsCompilation: no
Packaged: 2021-02-08 00:11:07 UTC; richie
Repository: CRAN
Date/Publication: 2021-02-08 05:50:02 UTC
